@@ -11,7 +11,7 @@ use DateTime::Format::Strptime;
 use List::Util qw(any);
 use Travel::Status::DE::HAFAS::Stop;
 
-our $VERSION = '5.04';
+our $VERSION = '5.05';
 
 Travel::Status::DE::HAFAS::Journey->mk_ro_accessors(
 	qw(datetime sched_datetime rt_datetime
@@ -89,16 +89,30 @@ sub new {
 
 	my $datetime_ref;
 
-	if ( @{ $journey->{stopL} // [] } or $journey->{stbStop} ) {
-		my $date_ref = ( split( qr{[|]}, $jid ) )[4];
-		if ( length($date_ref) < 7 ) {
-			warn("HAFAS, not even once -- midnight crossing may be bogus");
-		}
-		if ( length($date_ref) == 7 ) {
-			$date_ref = "0${date_ref}";
+	if ( @{ $journey->{stopL} // [] } or $journey->{stbStop}) {
+		my ($date_ref, $parse_fmt);
+		if ($jid =~ /#/) {
+			# ÖBB Journey ID - technically we ought to use Europe/Vienna tz
+			#  but let's not get into that...
+			$date_ref = ( split( /#/, $jid ) )[12];
+			$parse_fmt = '%d%m%y';
+			if ( length($date_ref) < 5 ) {
+				warn("HAFAS, not even once -- midnight crossing may be bogus -- date_ref $date_ref");
+			} elsif ( length($date_ref) == 5 ) {
+				$date_ref = "0${date_ref}";
+			}
+		} else {
+			# DB Journey ID
+			$date_ref = ( split( qr{[|]}, $jid ) )[4];
+			$parse_fmt = '%d%m%Y';
+			if ( length($date_ref) < 7 ) {
+				warn("HAFAS, not even once -- midnight crossing may be bogus -- date_ref $date_ref");
+			} elsif ( length($date_ref) == 7 ) {
+				$date_ref = "0${date_ref}";
+			}
 		}
 		$datetime_ref = DateTime::Format::Strptime->new(
-			pattern   => '%d%m%Y',
+			pattern   => $parse_fmt,
 			time_zone => 'Europe/Berlin'
 		)->parse_datetime($date_ref);
 	}
@@ -398,7 +412,7 @@ journey received by Travel::Status::DE::HAFAS
 
 =head1 VERSION
 
-version 5.04
+version 5.05
 
 =head1 DESCRIPTION
 
@@ -572,8 +586,9 @@ see above.
 
 =item $journey->polyline (journey only)
 
-List of geocoordinates that describe the train's route. Each list entry is
-a hash with the following keys.
+List of geocoordinates that describe the train's route. Only available if the
+HAFAS object constructor was passed a true B<with_polyline> value.  Each list
+entry is a hash with the following keys.
 
 =over
 
